@@ -10,6 +10,7 @@ import requests
 import math
 import imgviz
 import sys
+from distutils.version import StrictVersion
 
 from qtpy import QtCore
 from qtpy.QtCore import Qt
@@ -251,9 +252,6 @@ class MainWindow(QtWidgets.QMainWindow):
         self.shape_dock.setObjectName('Labels')
         self.shape_dock.setWidget(self.labelList)
 
-
-
-
         self.uniqLabelList = UniqueLabelQListWidget()
         self.uniqLabelList.setToolTip(self.tr(
             "Select label to start annotating for it. "
@@ -338,8 +336,8 @@ class MainWindow(QtWidgets.QMainWindow):
         shortcuts = self._config['shortcuts']
         quit = action(self.tr('&Quit'), self.close, shortcuts['quit'], 'quit',
                       self.tr('Quit application'))
-        restart = action(self.tr('&Restart'), self.reload, 'restart',
-                self.tr('Restart application'))
+        restart = action(text=self.tr('&Restart'), slot=self.reload, icon='restart',
+                tip=self.tr('Restart application'))
         open_ = action(self.tr('&Open'),
                        self.openFile,
                        shortcuts['open'],
@@ -494,6 +492,16 @@ class MainWindow(QtWidgets.QMainWindow):
             tip='Remove selected point from polygon',
             enabled=False,
         )
+        
+        autoPoint = action(
+            text='Auto Segmentation',
+            slot=self.autoSeg,
+            icon='edit',
+            shortcut=shortcuts['auto_segmentation'],
+            tip='Auto Segmentation',
+            enabled=True,
+        )
+
 
         undo = action(self.tr('Undo'), self.undoShapeEdit,
                       shortcuts['undo'], 'undo',
@@ -506,10 +514,10 @@ class MainWindow(QtWidgets.QMainWindow):
                          icon='eye', tip=self.tr('Show all polygons'),
                          enabled=True)
 
-        hideOthers = action(self.tr('&Immersive mode'),
-                            self.immersiveMode,
+        hideOthers = action(text=self.tr('&Immersive mode'),
+                            slot=self.immersiveMode,
                             icon='focus', tip=self.tr('Hide other polygons when creating polygon'),
-                            checkable=True, checked=self._config['hide_others'], enabled=True)
+                            checkable=True, enabled=True)
         hideOthers.setChecked(self._config['hide_others'])
         
         help = action(self.tr('&About'), self.about, icon='help',
@@ -631,7 +639,7 @@ class MainWindow(QtWidgets.QMainWindow):
             toggleKeepPrevMode=toggle_keep_prev_mode,
             delete=delete, edit=edit, copy=copy,
             undoLastPoint=undoLastPoint, undo=undo,
-            addPointToEdge=addPointToEdge, removePoint=removePoint,
+            addPointToEdge=addPointToEdge, removePoint=removePoint, autoPoint=autoPoint,
             createMode=createMode, editMode=editMode,
             createRectangleMode=createRectangleMode,
             createCircleMode=createCircleMode,
@@ -679,6 +687,7 @@ class MainWindow(QtWidgets.QMainWindow):
                 undoLastPoint,
                 addPointToEdge,
                 removePoint,
+                autoPoint,
             ),
             onLoadActive=(
                 close,
@@ -1006,7 +1015,10 @@ class MainWindow(QtWidgets.QMainWindow):
     def reload(self):
         self.close()
         fn = osp.join(osp.dirname(osp.realpath(__file__)), '__main__.py')
-        sys.exit(os.execl(sys.executable, sys.executable, *sys.argv))
+        if platform.system() == 'Windows':    # Windows
+            subprocess.check_call([sys.executable, "labelme+"])
+        else:
+            sys.exit(os.execl(sys.executable, sys.executable, *sys.argv))
     
     def about(self):
         return QtWidgets.QMessageBox.about(
@@ -1025,26 +1037,16 @@ class MainWindow(QtWidgets.QMainWindow):
             subprocess.call(('xdg-open', osp.join(osp.dirname(osp.realpath(__file__)), 'README.md')))
             
     def checkUpdate(self):
-        def compare(left, right):
-            left_vars = map(int, left.split('.'))
-            right_vars = map(int, right.split('.'))
-            for a, b in zip_longest(left_vars, right_vars, fillvalue = 0):
-                if a > b:
-                    return '>'
-                elif a < b:
-                    return '<'
-            return '='
-        
         if osp.isfile('version.txt'):
             os.remove('version.txt')
         url= "https://raw.githubusercontent.com/LilactheGreat/labelme/master/version.txt"
         os.system("curl " + url + " > version.txt")
         with open("version.txt", 'r', encoding='utf-8') as f:
-            newversion = f.read()
-        if compare(newversion[0], __version__) == '<':
+            newversion = f.readlines()
+        if StrictVersion(__version__) < StrictVersion(str(newversion[0])):
             buttonReply = QtWidgets.QMessageBox.question(
                 self, 'Checking Version', '\nLatest Version : %s\nCurrent Version : %s\n%s'%(
-                    str(newversion), __version__, 'Newer version is available. Wanna update now?'),
+                    newversion[0], __version__, 'Newer version is available. Wanna update now?'),
                  QtWidgets.QMessageBox.Yes | QtWidgets.QMessageBox.No, QtWidgets.QMessageBox.No)
             if buttonReply == QtWidgets.QMessageBox.Yes:
                 self.close()
@@ -1054,8 +1056,8 @@ class MainWindow(QtWidgets.QMainWindow):
                 sys.exit(self.reload())
         else:
             return QtWidgets.QMessageBox.about(
-                self, 'Checking Version', '\nCurrent Version : %s\nLatest Version : %s\n%s'%(
-                    __version__, str(newversion), 'No available update'))
+                self, 'Checking Version', '\nLatest Version : %sCurrent Version : %s\n%s'%(
+                    newversion[0], __version__, 'No new version is available'))
         
     def darkModeToggle(self):
         app = QtWidgets.QApplication.instance()
@@ -1077,14 +1079,18 @@ class MainWindow(QtWidgets.QMainWindow):
         if self.canvas.immersive_ok:
             if self.actions.hideOthers.isChecked() == True:
                 self.actions.hideOthers.setChecked(False)
+                self.canvas.immersive = False
             elif self.actions.hideOthers.isChecked() == False:
                 self.actions.hideOthers.setChecked(True)
-        elif not self.canvas.immersive_ok:
+                self.canvas.immersive = True
+        elif self.canvas.immersive_ok == False:
             if self.actions.hideOthers.isChecked() == True:
+                self.actions.hideOthers.setChecked(True)
                 self.canvas.immersive = True
             elif self.actions.hideOthers.isChecked() == False:
+                self.actions.hideOthers.setChecked(False)
                 self.canvas.immersive = False
-    
+        
     def toggleDrawingSensitive(self, drawing=True):
         """Toggle drawing sensitive.
 
@@ -1094,6 +1100,12 @@ class MainWindow(QtWidgets.QMainWindow):
         self.actions.undoLastPoint.setEnabled(drawing)
         self.actions.undo.setEnabled(not drawing)
         self.actions.delete.setEnabled(not drawing)
+        self.actions.createMode.setEnabled(not drawing)
+        self.actions.createRectangleMode.setEnabled(not drawing)
+        self.actions.createCircleMode.setEnabled(not drawing)
+        self.actions.createLineMode.setEnabled(not drawing)
+        self.actions.createPointMode.setEnabled(not drawing)
+        self.actions.createLineStripMode.setEnabled(not drawing)
 
     def toggleDrawMode(self, edit=True, createMode='polygon'):
         self.canvas.setEditing(edit)
@@ -1515,7 +1527,8 @@ class MainWindow(QtWidgets.QMainWindow):
             if self.actions.hideOthers.isChecked() == True:
                 self.canvas.keyboard_con()
                 self.canvas.immersive_first = True
-            self.canvas.immersive_ok = False
+                self.canvas.immersive_ok = False
+            self.canvas.drawend = True
         else:
             self.canvas.undoLastLine()
             self.canvas.shapesBackups.pop()
@@ -1943,6 +1956,7 @@ class MainWindow(QtWidgets.QMainWindow):
 
     def saveFileAs(self, _value=False):
         assert not self.image.isNull(), "cannot save empty image"
+        self.canvas.dialog = True
         if self.hasLabels():
             self._saveFile(self.saveFileDialog())
 
@@ -1971,11 +1985,13 @@ class MainWindow(QtWidgets.QMainWindow):
                 self.currentPath(), basename + LabelFile.suffix
             )
         filename = dlg.getSaveFileName(
-            self, self.tr('Choose File'), default_labelfile_name,
-            self.tr('Label files (*%s)') % LabelFile.suffix)
-        if QT5:
+            self,
+            self.tr("Choose File"),
+            default_labelfile_name,
+            self.tr("Label files (*%s)") % LabelFile.suffix,
+        )
+        if isinstance(filename, tuple):
             filename, _ = filename
-        filename = str(filename)
         return filename
 
     def _saveFile(self, filename):
@@ -2092,6 +2108,30 @@ class MainWindow(QtWidgets.QMainWindow):
             if self.noShapes():
                 for action in self.actions.onShapesPresent:
                     action.setEnabled(False)
+                    
+    def autoSeg(self):
+        def format_shape(s):
+                return dict(
+                    label=s.label.encode('utf-8') if PY2 else s.label,
+                    points=[(p.x(), p.y()) for p in s.points],
+                    group_id=s.group_id,
+                    shape_type=s.shape_type,
+                    flags=s.flags
+                )
+        
+        def getRect(pt1):
+            x1, y1 = pt1[0][0], pt1[0][1]
+            x3, y3 = pt1[1][0], pt1[1][1]
+            x2, y2 = x3, y1
+            x4, y4 = x1, y3
+            return ([x1, y1], [x2, y2], [x3, y3], [x4, y4])
+        
+        item = self.currentItem()
+        shapes = format_shape(item.shape())
+        rect_xy = getRect(list(shapes['points']))
+        print(rect_xy)
+        
+        # 이 좌표로 이미지에서 크롭 하시면 될 것 같습니다.
 
     def copyShape(self):
         self.canvas.endMove(copy=True)
