@@ -42,14 +42,14 @@ class Canvas(QtWidgets.QWidget):
     def __init__(self, *args, **kwargs):
         self.epsilon = kwargs.pop('epsilon', 10.0)
         self.double_click = kwargs.pop('double_click', 'None')
-        self.cross_onoff = kwargs.pop('cross_hair')
-        self.cross_temp = 0
-        self.hide_others = kwargs.pop('hide_others')
         if self.double_click not in [None, 'close']:
             raise ValueError(
                 'Unexpected value for double_click event: {}'
                 .format(self.double_click)
             )
+        self.cross_onoff = kwargs.pop('cross_hair')
+        self.cross_temp = 0
+        self.hide_others = kwargs.pop('hide_others')
         super(Canvas, self).__init__(*args, **kwargs)
         # Initialise local state.
         self.mode = self.EDIT
@@ -99,6 +99,7 @@ class Canvas(QtWidgets.QWidget):
         self.immersive_ok = False
         self.keyboard_button = pynput.keyboard.Controller()
         self.keyboard_key = pynput.keyboard.Key
+        self.enddraw = False
 
 
         fn = osp.join(osp.dirname(osp.realpath(__file__)), 'crossSave.txt')
@@ -381,13 +382,16 @@ class Canvas(QtWidgets.QWidget):
             pos = self.transformPos(ev.posF())
         if ev.button() == QtCore.Qt.LeftButton:
             if self.drawing():
-                self.immersive_ok = True
-                if self.hide_others:
+                if len(self.shapes) != 0:
+                    if self.hide_others:
+                        self.hide_others = False
+                        self.immersive = True
+                    if self.immersive and self.immersive_first:
+                        self.immersive_ok = True
+                        self.keyboard_con()
+                        self.immersive_first = False
+                else:
                     self.keyboard_con()
-                    self.hide_others = False
-                if self.immersive and self.immersive_first:
-                    self.keyboard_con()
-                    self.immersive_first = False
                 if self.current:
                     # Add point to existing shape.
                     if self.createMode == 'polygon':
@@ -767,9 +771,11 @@ class Canvas(QtWidgets.QWidget):
             if self.immersive:
                 self.keyboard_con()
                 self.immersive_first = True
+                self.immersive_ok = False
             self.current = None
             self.drawingPolygon.emit(False)
             self.update()
+            self.enddraw = True
         elif key == QtCore.Qt.Key_Return and self.canCloseShape():
             self.finalise()
 
